"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.camelize = camelize;
exports.snakify = snakify;
function isPlainObject(maybeObject) {
  return (typeof maybeObject === "undefined" ? "undefined" : _typeof(maybeObject)) === "object" && Object.keys(Object.getPrototypeOf(maybeObject)).length === 0;
}

function camelizeString(str) {
  return str.replace(/_(\w)/g, function (match) {
    return match[1].toUpperCase();
  });
}

function snakifyString(str) {
  return str.replace(/[A-Z]/g, function (match) {
    return "_" + match[0];
  }).toLowerCase();
}

function deeplyMapKeys(object, mapper) {
  var mappedObject = {};
  Object.keys(object).forEach(function (key) {
    var mappedKey = mapper(key);
    var mappedValue = isPlainObject(object[key]) ? deeplyMapKeys(object[key], mapper) : object[key];
    mappedObject[mappedKey] = mappedValue;
  });
  return mappedObject;
}

function camelize(object) {
  if (!object || !isPlainObject(object)) {
    throw new TypeError("`object` is not a plain object");
  }
  return deeplyMapKeys(object, camelizeString);
}

function snakify(object) {
  if (!object || !isPlainObject(object)) {
    throw new TypeError("`object` is not a plain object");
  }
  return deeplyMapKeys(object, snakifyString);
}